==> dto-1.0.1-RELEASE-sources.jar: de/jaggl/dto/lists/PrimitiveList.java <==
package de.jaggl.dto.lists;

import com.thoughtworks.xstream.annotations.XStreamAlias;

import de.jaggl.dto.Dto;

@XStreamAlias("primitives")
public final class PrimitiveList extends AbstractList<Object>
{

    public PrimitiveList()
    {
        super();
    }

    public void add(byte value)
    {
        data.add(Byte.valueOf(value));
    }

    public void add(boolean value)
    {
        data.add(Boolean.valueOf(value));
    }

    public void add(short value)
    {
        data.add(Short.valueOf(value));
    }

    public void add(int value)
    {
        data.add(Integer.valueOf(value));
    }

    public void add(long value)
    {
        data.add(Long.valueOf(value));
    }

    public void add(float value)
    {
        data.add(Float.valueOf(value));
    }

    public void add(double value)
    {
        data.add(Double.valueOf(value));
    }

    public void add(char value)
    {
        data.add(Character.valueOf(value));
    }

    public void add(String value)
    {
        data.add(value);
    }

    public void add(Dto value)
    {
        data.add(value);
    }

    public void add(ByteList value)
    {
        data.add(value);
    }

    public void add(BooleanList value)
    {
        data.add(value);
    }

    public void add(ShortList value)
    {
        data.add(value);
    }

    public void add(IntegerList value)
    {
        data.add(value);
    }

    public void add(LongList value)
    {
        data.add(value);
    }

    public void add(FloatList value)
    {
        data.add(value);
    }

    public void add(DoubleList value)
    {
        data.add(value);
    }

    public void add(CharacterList value)
    {
        data.add(value);
    }

    public void add(StringList value)
    {
        data.add(value);
    }

    public void add(DtoList value)
    {
        data.add(value);
    }

    public void add(PrimitiveList value)
    {
        data.add(value);
    }

    public void addNull()
    {
        data.add(null);
    }

    @Override
    public String toString()
    {
        return String.format("ListList %s", super.toString());
    }

}

==> dto-1.3.0-RELEASE-sources.jar: de/jaggl/dto/lists/PrimitiveList.java <==
package de.jaggl.dto.lists;

import java.sql.Date;

import com.thoughtworks.xstream.annotations.XStreamAlias;

import de.jaggl.dto.Dto;

@XStreamAlias("primitives")
public final class PrimitiveList extends AbstractList<Object>
{

    public PrimitiveList()
    {
        super();
    }

    public void add(byte value)
    {
        data.add(Byte.valueOf(value));
    }

    public void add(boolean value)
    {
        data.add(Boolean.valueOf(value));
    }

    public void add(short value)
    {
        data.add(Short.valueOf(value));
    }

    public void add(int value)
    {
        data.add(Integer.valueOf(value));
    }

    public void add(long value)
    {
        data.add(Long.valueOf(value));
    }

    public void add(float value)
    {
        data.add(Float.valueOf(value));
    }

    public void add(double value)
    {
        data.add(Double.valueOf(value));
    }

    public void add(char value)
    {
        data.add(Character.valueOf(value));
    }

    public void add(String value)
    {
        data.add(value);
    }

    public void add(Date value)
    {
        data.add(value != null ? new Date(value.getTime()) : null);
    }

    public void add(Dto value)
    {
        data.add(value);
    }

    public void add(ByteList value)
    {
        data.add(value);
    }

    public void add(BooleanList value)
    {
        data.add(value);
    }

    public void add(ShortList value)
    {
        data.add(value);
    }

    public void add(IntegerList value)
    {
        data.add(value);
    }

    public void add(LongList value)
    {
        data.add(value);
    }

    public void add(FloatList value)
    {
        data.add(value);
    }

    public void add(DoubleList value)
    {
        data.add(value);
    }

    public void add(CharacterList value)
    {
        data.add(value);
    }

    public void add(StringList value)
    {
        data.add(value);
    }

    public void add(DateList value)
    {
        data.add(value);
    }

    public void add(DtoList value)
    {
        data.add(value);
    }

    public void add(PrimitiveList value)
    {
        data.add(value);
    }

    public void addNull()
    {
        data.add(null);
    }

    @Override
    public String toString()
    {
        return String.format("ListList %s", super.toString());
    }

}
